winmm mapper open patch

Robert Reif reif at earthlink.net
Sat Jun 5 19:11:29 CDT 2004


Don't try to map the mapper device.
-------------- next part --------------
Index: dlls/winmm/winmm.c
===================================================================
RCS file: /home/wine/wine/dlls/winmm/winmm.c,v
retrieving revision 1.36
diff -u -r1.36 winmm.c
--- dlls/winmm/winmm.c	1 Jun 2004 19:40:48 -0000	1.36
+++ dlls/winmm/winmm.c	6 Jun 2004 00:05:32 -0000
@@ -2502,10 +2502,10 @@
 
         TRACE("dwRet = %s\n", WINMM_ErrorToString(dwRet));
         if (dwRet != WAVERR_BADFORMAT ||
-            (dwFlags & (WAVE_MAPPED|WAVE_FORMAT_DIRECT)) != 0) break;
+            ((dwFlags & (WAVE_MAPPED|WAVE_FORMAT_DIRECT)) != 0) || (uDeviceID == WAVE_MAPPER)) break;
         /* if we ask for a format which isn't supported by the physical driver, 
          * let's try to map it through the wave mapper (except, if we already tried
          * or user didn't allow us to use acm codecs)
          */
         dwFlags |= WAVE_MAPPED;
         /* we shall loop only one */
@@ -2502,10 +2502,10 @@
         /* if we ask for a format which isn't supported by the physical driver, 
          * let's try to map it through the wave mapper (except, if we already tried
-         * or user didn't allow us to use acm codecs)
+         * or user didn't allow us to use acm codecs or the device is already the mapper)
          */
         dwFlags |= WAVE_MAPPED;


More information about the wine-patches mailing list